@@ -199,6 +199,13 @@ if hasattr( pysvn.wc_notify_action, 'update_broken_lock' ):
     wc_notify_action_map[ pysvn.wc_notify_action.foreign_copy_begin ] = 'foreign_copy_begin'
     wc_notify_action_map[ pysvn.wc_notify_action.move_broken ] = 'move_broken'
 
+# new in svn 1.9
+if hasattr( pysvn.wc_notify_action, 'cleanup_external' ):
+    wc_notify_action_map[ pysvn.wc_notify_action.cleanup_external ] = 'cleanup_external'
+    wc_notify_action_map[ pysvn.wc_notify_action.failed_requires_target ] = 'failed_requires_target'
+    wc_notify_action_map[ pysvn.wc_notify_action.info_external ] = 'info_external'
+    wc_notify_action_map[ pysvn.wc_notify_action.commit_finalizing ] = 'commit_finalizing'
+
 class SvnCommand:
     def __init__( self, progname ):
         self.progname = progname
@@ -677,6 +684,7 @@ class SvnCommand:
 
         for arg in positional_args:
             all_files = self.client.ls( arg, revision=revision, recurse=recurse )
+            all_files.sort( key=self.__sortKeyLsList )
             if verbose:
                 for file in all_files:
                     args = {}
@@ -690,6 +698,9 @@ class SvnCommand:
                 for file in all_files:
                     print( '%(name)s' % file )
 
+    def __sortKeyLsList( self, entry ):
+        return entry['name']
+
     def cmd_list( self, args ):
         recurse = args.getBooleanOption( '--recursive', True )
         revision = args.getOptionalRevision( '--revision', 'head' )
@@ -741,9 +752,13 @@ class SvnCommand:
                 recurse=recurse, dry_run=dry_run, notice_ancestry=notice_ancestry )
 
     def cmd_mkdir( self, args ):
-        msg = args.getOptionalValue( '--message', '' )
-        if msg == '':
-            msg = self.getLogMessage()
+        if args.haveOption( '--message' ):
+            msg = args.getOptionalValue( '--message', '' )
+            if msg == '':
+                msg = self.getLogMessage()
+
+        else:
+            msg = ''
 
         self.client.mkdir( args.getPositionalArgs( 1, 1 )[0], msg )
 
@@ -752,6 +767,22 @@ class SvnCommand:
         self.client.move( positional_args[0], positional_args[1] )
     cmd_mv = cmd_move
 
+    def cmd_patch( self, args ):
+        dry_run = args.getBooleanOption( '--dry-run', True )
+        reverse = args.getBooleanOption( '--reverse', True )
+        ignore_whitespace = args.getBooleanOption( '--ignore-whitespace', True )
+        remove_tempfiles = not args.getBooleanOption( '--no-remove-tempfiles', True )
+
+        patch_path, wc_dir_path = args.getPositionalArgs( 2, 2 )
+        abs_patch_path = os.path.abspath( patch_path )
+        abs_wc_dir_path = os.path.abspath( wc_dir_path )
+
+        self.client.patch( abs_patch_path, abs_wc_dir_path,
+                            dry_run=dry_run,
+                            reverse=reverse,
+                            ignore_whitespace=ignore_whitespace,
+                            remove_tempfiles=remove_tempfiles )
+
     def key_props_by_path( self, a ):
         return a[0]
 
@@ -1053,6 +1084,7 @@ long_opt_info = {
     '--no-auto-props': 0,       # disable automatic properties
     '--no-diff-deleted': 0,     # do not print differences for deleted files
     '--no-ignore': 0,           # disregard default and svn:ignore property ignores
+    '--no-remove-tempfiles': 0, # do not remove temp files
     '--non-interactive': 0,     # do no interactive prompting
     '--notice-ancestry': 0,     # notice ancestry when calculating differences
     '--old': 1,                 # use ARG as the older target
@@ -1269,7 +1301,7 @@ class SvnArguments:
     def getPositionalArgs( self, min_args, max_args=0 ):
         # check min and max then return the list
         if len(self.positional_args) < min_args:
-            raise CommandError( 'too few arguments - need atlease %d' % min_args )
+            raise CommandError( 'too few arguments - need at least %d' % min_args )
         if max_args != 0 and len(self.positional_args) > max_args:
             raise CommandError( 'too many arguments - need no more then %d' % max_args )
 
