@@ -87,6 +87,12 @@ elif pymaj == 3 and pymin == 2:
 elif pymaj == 3 and pymin == 3:
     install_dir = '/Library/Frameworks/Python.framework/Versions/3.3/lib/python3.3/site-packages'
 
+elif pymaj == 3 and pymin == 4:
+    install_dir = '/Library/Frameworks/Python.framework/Versions/3.4/lib/python3.4/site-packages'
+
+elif pymaj == 3 and pymin == 5:
+    install_dir = '/Library/Frameworks/Python.framework/Versions/3.5/lib/python3.5/site-packages'
+
 else:
     raise RuntimeError( 'Unsupported version of python' )
 
