@@ -1,10 +1,8 @@
 print( 'Info: setup_version_handling.py' )
 import sys
-import time
-import os
-
 sys.path.insert( 0, '..\\..\\Source')
 import pysvn
+import time
 
 py_maj = sys.version_info[0]
 py_min = sys.version_info[1]
@@ -45,29 +43,30 @@ print( 'Info: %r' % (branding,) )
 f.write( pysvn_iss_text % branding )
 f.close()
 
-all_dlls = [dll for dll in os.listdir( 'tmp' ) if dll.lower().endswith( '.dll' )]
-
-
-msvc90_dlls = [
-    R'c:\Program Files (x86)\Microsoft Visual Studio 9.0\vc\redist\x86\Microsoft.VC90.CRT\Microsoft.VC90.CRT.manifest',
-    R'c:\Program Files (x86)\Microsoft Visual Studio 9.0\vc\redist\x86\Microsoft.VC90.CRT\msvcm90.dll',
-    R'c:\Program Files (x86)\Microsoft Visual Studio 9.0\vc\redist\x86\Microsoft.VC90.CRT\msvcp90.dll',
-    R'c:\Program Files (x86)\Microsoft Visual Studio 9.0\vc\redist\x86\Microsoft.VC90.CRT\msvcr90.dll',
-    ]
-
 if py_maj == 3:
-    all_dlls.extend( msvc90_dlls )
+    msvc_system_files_iss = 'msvc90_system_files.iss'
 
 elif py_maj == 2 and py_min >= 6:
-    all_dlls.extend( msvc90_dlls )
+    msvc_system_files_iss = 'msvc90_system_files.iss'
 
 else:
-    raise RuntimeError( 'Unsupport python version' )
+    msvc_system_files_iss = 'msvc71_system_files.iss'
 
-print( 'Info: Creating system_files.iss' )
-f = open( 'tmp\\system_files.iss', 'w' )
-for dll in all_dlls:
-    f.write( 'Source: "%s"; DestDir: "{app}"; Flags: ignoreversion\n' % (dll,) )
+
+
+print( 'Info: Creating %s from pysvn.iss' % msvc_system_files_iss )
+f = open( msvc_system_files_iss, 'r' )
+pysvn_iss_text = f.read()
+f.close()
+
+f = open( 'tmp\\msvc_system_files.iss', 'w' )
+branding = {
+        'py_maj': py_maj,
+        'py_min': py_min,
+        'pysvn_version_string': pysvn_version_string,
+        }
+print( 'Info: %r' % (branding,) )
+f.write( pysvn_iss_text % branding )
 f.close()
 
 print( 'Info: Create setup_copy.cmd' )
