@@ -231,7 +231,7 @@ Py::Object pysvn_client::cmd_import( const Py::Tuple &a_args, const Py::Dict &a_
         Py::Object py_revprop = args.getArg( name_revprops );
         if( !py_revprop.isNone() )
         {
-            revprops = hashOfStringsFromDistOfStrings( py_revprop, pool );
+            revprops = hashOfStringsFromDictOfStrings( py_revprop, pool );
         }
     }
 #else
