@@ -83,7 +83,7 @@ Py::Object pysvn_client::cmd_propdel( const Py::Tuple &a_args, const Py::Dict &a
         Py::Object py_revprop = args.getArg( name_revprops );
         if( !py_revprop.isNone() )
         {
-            revprops = hashOfStringsFromDistOfStrings( py_revprop, pool );
+            revprops = hashOfStringsFromDictOfStrings( py_revprop, pool );
         }
     }
 #endif
@@ -534,7 +534,7 @@ Py::Object pysvn_client::cmd_propset( const Py::Tuple &a_args, const Py::Dict &a
         Py::Object py_revprop = args.getArg( name_revprops );
         if( !py_revprop.isNone() )
         {
-            revprops = hashOfStringsFromDistOfStrings( py_revprop, pool );
+            revprops = hashOfStringsFromDictOfStrings( py_revprop, pool );
         }
     }
 #else
