@@ -1,6 +1,6 @@
 //
 // ====================================================================
-// Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
+// Copyright (c) 2003-2013 Barry A Scott.  All rights reserved.
 //
 // This software is licensed as described in the file LICENSE.txt,
 // which you should have received as part of this distribution.
@@ -27,11 +27,11 @@ PYSVN_STATIC_STRING( name_allow_unver_obstructions, "allow_unver_obstructions" )
 PYSVN_STATIC_STRING( name_author, "author" )
 PYSVN_STATIC_STRING( name_base_revision_for_url, "base_revision_for_url" )
 PYSVN_STATIC_STRING( name_callback_cancel, "callback_cancel" )
+PYSVN_STATIC_STRING( name_callback_conflict_resolver, "callback_conflict_resolver" )
 PYSVN_STATIC_STRING( name_callback_get_log_message, "callback_get_log_message" )
 PYSVN_STATIC_STRING( name_callback_get_login, "callback_get_login" )
 PYSVN_STATIC_STRING( name_callback_notify, "callback_notify" )
 PYSVN_STATIC_STRING( name_callback_progress, "callback_progress" )
-PYSVN_STATIC_STRING( name_callback_conflict_resolver, "callback_conflict_resolver" )
 PYSVN_STATIC_STRING( name_callback_ssl_client_cert_password_prompt, "callback_ssl_client_cert_password_prompt" )
 PYSVN_STATIC_STRING( name_callback_ssl_client_cert_prompt, "callback_ssl_client_cert_prompt" )
 PYSVN_STATIC_STRING( name_callback_ssl_server_prompt, "callback_ssl_server_prompt" )
@@ -41,8 +41,10 @@ PYSVN_STATIC_STRING( name_changelist, "changelist" )
 PYSVN_STATIC_STRING( name_changelists, "changelists" )
 PYSVN_STATIC_STRING( name_comment, "comment" )
 PYSVN_STATIC_STRING( name_commit_info_style, "commit_info_style" )
+PYSVN_STATIC_STRING( name_config_dir, "config_dir" )
 PYSVN_STATIC_STRING( name_conflict_choice, "conflict_choice" )
 PYSVN_STATIC_STRING( name_copy_as_child, "copy_as_child" )
+PYSVN_STATIC_STRING( name_copy_info, "copy_info" )
 PYSVN_STATIC_STRING( name_copyfrom_path, "copyfrom_path" )
 PYSVN_STATIC_STRING( name_copyfrom_revision, "copyfrom_revision" )
 PYSVN_STATIC_STRING( name_created_rev, "created_rev" )
@@ -73,6 +75,7 @@ PYSVN_STATIC_STRING( name_ignore_keywords, "ignore_keywords" )
 PYSVN_STATIC_STRING( name_ignore_mime_type, "ignore_mime_type" )
 PYSVN_STATIC_STRING( name_ignore_space, "ignore_space" )
 PYSVN_STATIC_STRING( name_ignore_unknown_node_types, "ignore_unknown_node_types" )
+PYSVN_STATIC_STRING( name_ignore_whitespace, "ignore_whitespace" )
 PYSVN_STATIC_STRING( name_include_merged_revisions, "include_merged_revisions" )
 PYSVN_STATIC_STRING( name_is_revision, "is_revision" )
 PYSVN_STATIC_STRING( name_keep_changelist, "keep_changelist" )
@@ -95,6 +98,7 @@ PYSVN_STATIC_STRING( name_node_kind, "node_kind" )
 PYSVN_STATIC_STRING( name_notice_ancestry, "notice_ancestry" )
 PYSVN_STATIC_STRING( name_number, "number" )
 PYSVN_STATIC_STRING( name_password, "password" )
+PYSVN_STATIC_STRING( name_patch_abspath, "patch_abspath" )
 PYSVN_STATIC_STRING( name_path, "path" )
 PYSVN_STATIC_STRING( name_peg_revision, "peg_revision" )
 PYSVN_STATIC_STRING( name_prop_changed, "prop_changed" )
@@ -104,10 +108,13 @@ PYSVN_STATIC_STRING( name_ranges_to_merge, "ranges_to_merge" )
 PYSVN_STATIC_STRING( name_record_only, "record_only" )
 PYSVN_STATIC_STRING( name_recurse, "recurse" )
 PYSVN_STATIC_STRING( name_relative_to_dir, "relative_to_dir" )
+PYSVN_STATIC_STRING( name_remove_tempfiles, "remove_tempfiles" )
 PYSVN_STATIC_STRING( name_repos_path, "repos_path" )
+PYSVN_STATIC_STRING( name_result_wrappers, "result_wrappers" )
+PYSVN_STATIC_STRING( name_reverse, "reverse" )
+PYSVN_STATIC_STRING( name_revision, "revision" )
 PYSVN_STATIC_STRING( name_revision1, "revision1" )
 PYSVN_STATIC_STRING( name_revision2, "revision2" )
-PYSVN_STATIC_STRING( name_revision, "revision" )
 PYSVN_STATIC_STRING( name_revision_end, "revision_end" )
 PYSVN_STATIC_STRING( name_revision_start, "revision_start" )
 PYSVN_STATIC_STRING( name_revprops, "revprops" )
@@ -117,23 +124,22 @@ PYSVN_STATIC_STRING( name_sources, "sources" )
 PYSVN_STATIC_STRING( name_src_revision, "src_revision" )
 PYSVN_STATIC_STRING( name_src_url_or_path, "src_url_or_path" )
 PYSVN_STATIC_STRING( name_strict_node_history, "strict_node_history" )
+PYSVN_STATIC_STRING( name_strip_count, "strip_count" )
 PYSVN_STATIC_STRING( name_summarize_kind, "summarize_kind" )
 PYSVN_STATIC_STRING( name_target_wcpath, "target_wcpath" )
 PYSVN_STATIC_STRING( name_time, "time" )
 PYSVN_STATIC_STRING( name_tmp_path, "tmp_path" )
 PYSVN_STATIC_STRING( name_to_url, "to_url" )
+PYSVN_STATIC_STRING( name_transaction_name, "transaction_name" )
 PYSVN_STATIC_STRING( name_unlock, "unlock" )
 PYSVN_STATIC_STRING( name_update, "update" )
 PYSVN_STATIC_STRING( name_url, "url" )
+PYSVN_STATIC_STRING( name_url_or_path, "url_or_path" )
 PYSVN_STATIC_STRING( name_url_or_path1, "url_or_path1" )
 PYSVN_STATIC_STRING( name_url_or_path2, "url_or_path2" )
-PYSVN_STATIC_STRING( name_url_or_path, "url_or_path" )
 PYSVN_STATIC_STRING( name_username, "username" )
 PYSVN_STATIC_STRING( name_utf8, "utf-8" )
-PYSVN_STATIC_STRING( name_transaction_name, "transaction_name" )
-PYSVN_STATIC_STRING( name_config_dir, "config_dir" )
-PYSVN_STATIC_STRING( name_result_wrappers, "result_wrappers" )
-PYSVN_STATIC_STRING( name_copy_info, "copy_info" )
+PYSVN_STATIC_STRING( name_wc_dir_abspath, "wc_dir_abspath" )
 
 PYSVN_STATIC_PY_STRING_P( py_name_callback_cancel )
 PYSVN_STATIC_PY_STRING_P( py_name_callback_conflict_resolver )
