@@ -1,5 +1,5 @@
 #!/bin/sh
-export PYTHONPATH=${WORKDIR}/Source
+export PYTHONPATH=${BUILDER_TOP_DIR}/Source
 export LD_LIBRARY_PATH=${SVNCPP_LIB}
 export DYLD_LIBRARY_PATH=${SVNCPP_LIB}
 ${PYTHON} $*
