@@ -25,7 +25,7 @@ class SetupError(Exception):
     pass
 
 # version of PyCXX that we require
-pycxx_version = (6, 2, 4)
+pycxx_version = (6, 2, 6)
 
 _debug = False
 
@@ -70,6 +70,7 @@ class Options:
         '--svn-bin-dir':        (1, '<dir>'),
         '--svn-root-dir':       (1, '<dir>'),
         '--verbose':            (0, None),
+        '--disable-deprecated-functions-warnings': (0, None),
         }
 
     def __init__( self, argv ):
@@ -248,6 +249,7 @@ class Setup:
             Source( self.c_pysvn, 'pysvn_client_cmd_list.cpp', pysvn_headers ),
             Source( self.c_pysvn, 'pysvn_client_cmd_lock.cpp', pysvn_headers ),
             Source( self.c_pysvn, 'pysvn_client_cmd_merge.cpp', pysvn_headers ),
+            Source( self.c_pysvn, 'pysvn_client_cmd_patch.cpp', pysvn_headers ),
             Source( self.c_pysvn, 'pysvn_client_cmd_prop.cpp', pysvn_headers ),
             Source( self.c_pysvn, 'pysvn_client_cmd_revprop.cpp', pysvn_headers ),
             Source( self.c_pysvn, 'pysvn_client_cmd_switch.cpp', pysvn_headers ),
@@ -306,20 +308,31 @@ class Setup:
 
         return 0
 
+    def __filterTestCases( self, all_test_case_candidates ):
+        all_test_cases = []
+        for tc in all_test_case_candidates:
+            if tc.isTestSupported():
+                all_test_cases.append( tc )
+            else:
+                print( 'Info: svn testcase %s skipped - svn version too old' % (tc.test_name,) )
+
+        return all_test_cases
+
     def generateTestMakefile( self ):
         print( 'Info: Creating Makefile for Tests' )
 
-        all_normal_test_cases = [
+        all_normal_test_cases = self.__filterTestCases( [
             TestCase( self.c_pysvn, '01' ),
             TestCase( self.c_pysvn, '04' ),
             TestCase( self.c_pysvn, '05' ),
             TestCase( self.c_pysvn, '06' ),
             TestCase( self.c_pysvn, '07' ),
-            ]
+            TestCase( self.c_pysvn, '08', (1,7,0) ),
+            ] )
 
-        all_extra_test_cases = [
+        all_extra_test_cases = self.__filterTestCases( [
             TestCase( self.c_pysvn, '03' ),
-            ]
+            ] )
 
         all_test_cases = []
         all_test_cases.extend( all_normal_test_cases )
@@ -952,6 +965,12 @@ class MacOsxCompilerGCC(CompilerGCC):
     def __init__( self, setup ):
         CompilerGCC.__init__( self, setup )
 
+        self.macosx_deployment_target = os.environ.get( 'MACOSX_DEPLOYMENT_TARGET', None )
+        if self.macosx_deployment_target is None:
+            raise SetupError( 'Set environment variable MACOSX_DEPLOYMENT_TARGET to desired target' )
+
+        print( 'Info: MACOSX_DEPLOYMENT_TARGET is %s' % (self.macosx_deployment_target,) )
+
         if self.options.hasOption( '--arch' ):
             arch_options = ' '.join( ['-arch %s' % (arch,) for arch in self.options.getOption( '--arch' )] )
         else:
@@ -974,35 +993,25 @@ class MacOsxCompilerGCC(CompilerGCC):
                         '/sw/include/subversion-1',             # Darwin - Fink
                         '/usr/include/subversion-1',            # typical Linux
                         '/usr/local/include/subversion-1',      # typical *BSD
-                        '/usr/pkg/include/subversion-1',        # netbsd
                         ]
         self._find_paths_svn_bin = [
                         '/opt/local/bin',                        # Darwin - darwin ports
-                        '/sw/bin',                                # Darwin - Fink
-                        '/usr/bin',                                # typical Linux
+                        '/sw/bin',                               # Darwin - Fink
+                        '/usr/bin',                              # typical Linux
                         '/usr/local/bin',                        # typical *BSD
-                        '/usr/pkg/bin',                                # netbsd
                         ]
         self._find_paths_svn_lib = [
                         '/opt/local/lib',                       # Darwin - darwin ports
                         '/sw/lib',                              # Darwin - Fink
-                        '/usr/lib64',                           # typical 64bit Linux
                         '/usr/lib',                             # typical Linux
-                        '/usr/local/lib64',                     # typical 64bit Linux
                         '/usr/local/lib',                       # typical *BSD
-                        '/usr/pkg/lib',                         # netbsd
                         ]
         self._find_paths_apr_inc = [
                         '/opt/local/include/apr-1',             # Darwin - darwin ports
                         '/sw/include/apr-1',                    # Darwin - fink
                         '/usr/include/apr-1',                   # typical Linux
                         '/usr/local/apr/include/apr-1',         # Mac OS X www.metissian.com
-                        '/usr/pkg/include/apr-1',               # netbsd
-                        '/usr/include/apache2',                 # alternate Linux
-                        '/usr/include/httpd',                   # alternate Linux
-                        '/usr/local/include/apr-1',             # typical FreeBSD
-                        '/usr/local/include/apr0',              # typical *BSD
-                        '/usr/local/include/apache2',           # alternate *BSD
+                        '/Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX%s.sdk/usr/include/apr-1' % (self.macosx_deployment_target,),
                         ]
         self._find_paths_apr_util_inc = self._find_paths_apr_inc
         self._find_paths_apr_lib = [
@@ -1024,9 +1033,8 @@ class MacOsxCompilerGCC(CompilerGCC):
     def setupUtilities( self ):
         self._addVar( 'CCCFLAGS',
                                         '-g  '
-                                        '-no-long-double '
                                         '-Wall -fPIC -fexceptions -frtti '
-                                        '-I. -I%(APR_INC)s -I%(SVN_INC)s '
+                                        '-I. -I%(APR_INC)s -I%(APU_INC)s -I%(SVN_INC)s '
                                         '-D%(DEBUG)s' )
         self._addVar( 'LDEXE',          '%(CCC)s -g' )
 
@@ -1041,9 +1049,8 @@ class MacOsxCompilerGCC(CompilerGCC):
 
         py_cflags_list = [
                     '-g',
-                    '-no-long-double',
                     '-Wall -fPIC -fexceptions -frtti',
-                    '-I. -I%(APR_INC)s -I%(SVN_INC)s',
+                    '-I. -I%(APR_INC)s -I%(APU_INC)s -I%(SVN_INC)s',
                     '-DPYCXX_PYTHON_2TO3 -I%(PYCXX)s -I%(PYCXX_SRC)s -I%(PYTHON_INC)s',
                     '-D%(DEBUG)s',
                     ]
@@ -1093,9 +1100,9 @@ class UnixCompilerGCC(CompilerGCC):
                         '/usr/pkg/include/subversion-1',        # netbsd
                         ]
         self._find_paths_svn_bin = [
-                        '/usr/bin',                                # typical Linux
-                        '/usr/local/bin',                        # typical *BSD
-                        '/usr/pkg/bin',                                # netbsd
+                        '/usr/bin',                             # typical Linux
+                        '/usr/local/bin',                       # typical *BSD
+                        '/usr/pkg/bin',                         # netbsd
                         ]
         self._find_paths_svn_lib = [
                         '/usr/lib64',                           # typical 64bit Linux
@@ -1135,7 +1142,7 @@ class UnixCompilerGCC(CompilerGCC):
         self._addVar( 'CCCFLAGS',
                                         '-g  '
                                         '-Wall -fPIC -fexceptions -frtti '
-                                        '-I. -I%(APR_INC)s -I%(SVN_INC)s '
+                                        '-I. -I%(APR_INC)s -I%(APU_INC)s -I%(SVN_INC)s '
                                         '-D%(DEBUG)s' )
         self._addVar( 'LDEXE',          '%(CCC)s -g' )
 
@@ -1149,7 +1156,7 @@ class UnixCompilerGCC(CompilerGCC):
 
         py_cflags_list = [
                     '-Wall -fPIC -fexceptions -frtti',
-                    '-I. -I%(APR_INC)s -I%(SVN_INC)s',
+                    '-I. -I%(APR_INC)s -I%(APU_INC)s -I%(SVN_INC)s',
                     '-DPYCXX_PYTHON_2TO3 -I%(PYCXX)s -I%(PYCXX_SRC)s -I%(PYTHON_INC)s',
                     '-I%(PYTHON_ARCH_SPECIFIC_INC)s',
                     '-D%(DEBUG)s',
@@ -1163,6 +1170,10 @@ class UnixCompilerGCC(CompilerGCC):
             print( 'Info: Debug enabled' )
             py_cflags_list.append( '-g' )
 
+        if self.options.hasOption( '--disable-deprecated-functions-warnings' ):
+            print( 'Info: Disable deprecated functions warnings' )
+            py_cflags_list.append( '-Wno-deprecated-declarations' )
+
         self._addVar( 'CCCFLAGS',   ' '.join( py_cflags_list ) )
         self._addVar( 'LDLIBS',     ' '.join( self._getLdLibs() ) )
         self._addVar( 'LDSHARED',   '%(CCC)s -shared -g' )
@@ -1175,6 +1186,7 @@ class LinuxCompilerGCC(UnixCompilerGCC):
     def _getLdLibs( self ):
         py_ld_libs = [
                 '-L%(SVN_LIB)s',
+                '-L%(APR_LIB)s',
                 ]
         if not self.setup.options.hasOption( '--norpath' ):
             py_ld_libs.extend( [
@@ -1199,6 +1211,7 @@ class FreeBsdCompilerGCC(UnixCompilerGCC):
     def _getLdLibs( self ):
         py_ld_libs = [
                 '-L%(SVN_LIB)s',
+                '-L%(APR_LIB)s',
                 '-Wl,--rpath',
                 '-Wl,/usr/lib:/usr/local/lib',
                 '-lsvn_client-1',
@@ -1223,6 +1236,7 @@ class CygwinCompilerGCC(UnixCompilerGCC):
     def _getLdLibs( self ):
         py_ld_libs = [
                 '-L%(svn_lib_dir)s',
+                '-L%(apr_lib_dir)s',
                 '-L/usr/lib/python%d.%d/config -lpython%d.%d.dll' %
                     (sys.version_info[0], sys.version_info[1], sys.version_info[0], sys.version_info[1]),
                 '-lsvn_client-1',
@@ -1613,13 +1627,22 @@ class PysvnModuleInit(Source):
         self.ruleClean()
 
 class TestCase(Target):
-    def __init__( self, compiler, test_name ):
+    def __init__( self, compiler, test_name, required_version=None ):
         self.test_name = test_name
 
+        if required_version is None:
+            self.required_version = (1,0,0)
+
+        else:
+            self.required_version = required_version
+
         Target.__init__( self, compiler, [] )
 
         debug( 'TestCase:0x%8.8x.__init__( %r )' % (id(self), test_name) )
 
+    def isTestSupported( self ):
+        return self.compiler.getSvnVersion() >= self.required_version
+
     def __repr__( self ):
         return '<TestCase:0x%8.8x %s>' % (id(self), self.test_name)
 
