@@ -1,6 +1,6 @@
 #!/bin/sh
 # need to get rid of any symbolic links in the WORKDIR
-export WORKDIR=$( ${PYTHON} -c 'import os;os.chdir("..");print os.getcwd()' )
+export WORKDIR=$( ${PYTHON} -c 'import os;os.chdir("..");print( os.getcwd() )' )
 
 cd ${WORKDIR}/Tests
 echo WorkDir: ${WORKDIR}
